activity

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2024 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	ActivityService_Insert_FullMethodName = "/terrapi.v1.ActivityService/Insert"
	ActivityService_List_FullMethodName   = "/terrapi.v1.ActivityService/List"
)

Variables

var (
	InsertActivityRequest_Pointer_name = map[int32]string{
		0: "stdout",
		1: "stderr",
	}
	InsertActivityRequest_Pointer_value = map[string]int32{
		"stdout": 0,
		"stderr": 1,
	}
)

Enum value maps for InsertActivityRequest_Pointer.

var (
	Activity_Pointer_name = map[int32]string{
		0: "stdout",
		1: "stderr",
	}
	Activity_Pointer_value = map[string]int32{
		"stdout": 0,
		"stderr": 1,
	}
)

Enum value maps for Activity_Pointer.

var ActivityService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "terrapi.v1.ActivityService",
	HandlerType: (*ActivityServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Insert",
			Handler:    _ActivityService_Insert_Handler,
		},
		{
			MethodName: "List",
			Handler:    _ActivityService_List_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "activity/activity.proto",
}

ActivityService_ServiceDesc is the grpc.ServiceDesc for ActivityService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_activity_activity_proto protoreflect.FileDescriptor

Functions

func RegisterActivityServiceServer

func RegisterActivityServiceServer(s grpc.ServiceRegistrar, srv ActivityServiceServer)

Types

type Activities

type Activities struct {
	Activities []*Activity `protobuf:"bytes,1,rep,name=activities,proto3" json:"activities,omitempty"`
	// contains filtered or unexported fields
}

func (*Activities) Descriptor deprecated

func (*Activities) Descriptor() ([]byte, []int)

Deprecated: Use Activities.ProtoReflect.Descriptor instead.

func (*Activities) GetActivities

func (x *Activities) GetActivities() []*Activity

func (*Activities) ProtoMessage

func (*Activities) ProtoMessage()

func (*Activities) ProtoReflect

func (x *Activities) ProtoReflect() protoreflect.Message

func (*Activities) Reset

func (x *Activities) Reset()

func (*Activities) String

func (x *Activities) String() string

type Activity

type Activity struct {
	Id         int32            `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Deployment int32            `protobuf:"varint,2,opt,name=deployment,proto3" json:"deployment,omitempty"`
	Pointer    Activity_Pointer `protobuf:"varint,3,opt,name=pointer,proto3,enum=terrapi.v1.Activity_Pointer" json:"pointer,omitempty"`
	Message    string           `protobuf:"bytes,4,opt,name=message,proto3" json:"message,omitempty"`
	Timestamp  int32            `protobuf:"varint,5,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	// contains filtered or unexported fields
}

func (*Activity) Descriptor deprecated

func (*Activity) Descriptor() ([]byte, []int)

Deprecated: Use Activity.ProtoReflect.Descriptor instead.

func (*Activity) GetDeployment

func (x *Activity) GetDeployment() int32

func (*Activity) GetId

func (x *Activity) GetId() int32

func (*Activity) GetMessage

func (x *Activity) GetMessage() string

func (*Activity) GetPointer

func (x *Activity) GetPointer() Activity_Pointer

func (*Activity) GetTimestamp

func (x *Activity) GetTimestamp() int32

func (*Activity) ProtoMessage

func (*Activity) ProtoMessage()

func (*Activity) ProtoReflect

func (x *Activity) ProtoReflect() protoreflect.Message

func (*Activity) Reset

func (x *Activity) Reset()

func (*Activity) String

func (x *Activity) String() string

type ActivityServiceClient

type ActivityServiceClient interface {
	Insert(ctx context.Context, in *InsertActivityRequest, opts ...grpc.CallOption) (*InsertActivityResponse, error)
	List(ctx context.Context, in *ListActivityRequest, opts ...grpc.CallOption) (*Activities, error)
}

ActivityServiceClient is the client API for ActivityService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ActivityServiceServer

type ActivityServiceServer interface {
	Insert(context.Context, *InsertActivityRequest) (*InsertActivityResponse, error)
	List(context.Context, *ListActivityRequest) (*Activities, error)
	// contains filtered or unexported methods
}

ActivityServiceServer is the server API for ActivityService service. All implementations must embed UnimplementedActivityServiceServer for forward compatibility.

type Activity_Pointer

type Activity_Pointer int32
const (
	Activity_stdout Activity_Pointer = 0
	Activity_stderr Activity_Pointer = 1
)

func (Activity_Pointer) Descriptor

func (Activity_Pointer) Enum

func (Activity_Pointer) EnumDescriptor deprecated

func (Activity_Pointer) EnumDescriptor() ([]byte, []int)

Deprecated: Use Activity_Pointer.Descriptor instead.

func (Activity_Pointer) Number

func (Activity_Pointer) String

func (x Activity_Pointer) String() string

func (Activity_Pointer) Type

type InsertActivityRequest

type InsertActivityRequest struct {
	Deployment int32                         `protobuf:"varint,2,opt,name=deployment,proto3" json:"deployment,omitempty"`
	Pointer    InsertActivityRequest_Pointer `protobuf:"varint,3,opt,name=pointer,proto3,enum=terrapi.v1.InsertActivityRequest_Pointer" json:"pointer,omitempty"`
	Message    string                        `protobuf:"bytes,4,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*InsertActivityRequest) Descriptor deprecated

func (*InsertActivityRequest) Descriptor() ([]byte, []int)

Deprecated: Use InsertActivityRequest.ProtoReflect.Descriptor instead.

func (*InsertActivityRequest) GetDeployment

func (x *InsertActivityRequest) GetDeployment() int32

func (*InsertActivityRequest) GetMessage

func (x *InsertActivityRequest) GetMessage() string

func (*InsertActivityRequest) GetPointer

func (*InsertActivityRequest) ProtoMessage

func (*InsertActivityRequest) ProtoMessage()

func (*InsertActivityRequest) ProtoReflect

func (x *InsertActivityRequest) ProtoReflect() protoreflect.Message

func (*InsertActivityRequest) Reset

func (x *InsertActivityRequest) Reset()

func (*InsertActivityRequest) String

func (x *InsertActivityRequest) String() string

type InsertActivityRequest_Pointer

type InsertActivityRequest_Pointer int32
const (
	InsertActivityRequest_stdout InsertActivityRequest_Pointer = 0
	InsertActivityRequest_stderr InsertActivityRequest_Pointer = 1
)

func (InsertActivityRequest_Pointer) Descriptor

func (InsertActivityRequest_Pointer) Enum

func (InsertActivityRequest_Pointer) EnumDescriptor deprecated

func (InsertActivityRequest_Pointer) EnumDescriptor() ([]byte, []int)

Deprecated: Use InsertActivityRequest_Pointer.Descriptor instead.

func (InsertActivityRequest_Pointer) Number

func (InsertActivityRequest_Pointer) String

func (InsertActivityRequest_Pointer) Type

type InsertActivityResponse

type InsertActivityResponse struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*InsertActivityResponse) Descriptor deprecated

func (*InsertActivityResponse) Descriptor() ([]byte, []int)

Deprecated: Use InsertActivityResponse.ProtoReflect.Descriptor instead.

func (*InsertActivityResponse) GetId

func (x *InsertActivityResponse) GetId() int32

func (*InsertActivityResponse) ProtoMessage

func (*InsertActivityResponse) ProtoMessage()

func (*InsertActivityResponse) ProtoReflect

func (x *InsertActivityResponse) ProtoReflect() protoreflect.Message

func (*InsertActivityResponse) Reset

func (x *InsertActivityResponse) Reset()

func (*InsertActivityResponse) String

func (x *InsertActivityResponse) String() string

type ListActivityRequest

type ListActivityRequest struct {
	Offset int32 `protobuf:"varint,1,opt,name=offset,proto3" json:"offset,omitempty"`
	// contains filtered or unexported fields
}

func (*ListActivityRequest) Descriptor deprecated

func (*ListActivityRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListActivityRequest.ProtoReflect.Descriptor instead.

func (*ListActivityRequest) GetOffset

func (x *ListActivityRequest) GetOffset() int32

func (*ListActivityRequest) ProtoMessage

func (*ListActivityRequest) ProtoMessage()

func (*ListActivityRequest) ProtoReflect

func (x *ListActivityRequest) ProtoReflect() protoreflect.Message

func (*ListActivityRequest) Reset

func (x *ListActivityRequest) Reset()

func (*ListActivityRequest) String

func (x *ListActivityRequest) String() string

type UnimplementedActivityServiceServer

type UnimplementedActivityServiceServer struct{}

UnimplementedActivityServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedActivityServiceServer) Insert added in v1.1.0

func (UnimplementedActivityServiceServer) List added in v1.1.0

type UnsafeActivityServiceServer

type UnsafeActivityServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeActivityServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ActivityServiceServer will result in compilation errors.

Jump to