Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterDeploymentServiceServer(s grpc.ServiceRegistrar, srv DeploymentServiceServer)
- type Deployment
- func (*Deployment) Descriptor() ([]byte, []int)deprecated
- func (x *Deployment) GetModule() *DeploymentModule
- func (x *Deployment) GetRequest() *DeploymentRequest
- func (*Deployment) ProtoMessage()
- func (x *Deployment) ProtoReflect() protoreflect.Message
- func (x *Deployment) Reset()
- func (x *Deployment) String() string
- type DeploymentModule
- func (*DeploymentModule) Descriptor() ([]byte, []int)deprecated
- func (x *DeploymentModule) GetAddress() string
- func (x *DeploymentModule) GetName() string
- func (x *DeploymentModule) GetPassword() string
- func (x *DeploymentModule) GetPath() string
- func (x *DeploymentModule) GetUsername() string
- func (*DeploymentModule) ProtoMessage()
- func (x *DeploymentModule) ProtoReflect() protoreflect.Message
- func (x *DeploymentModule) Reset()
- func (x *DeploymentModule) String() string
- type DeploymentRequest
- func (*DeploymentRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeploymentRequest) GetAction() DeploymentRequest_Action
- func (x *DeploymentRequest) GetVariables() []*DeploymentRequestVariable
- func (*DeploymentRequest) ProtoMessage()
- func (x *DeploymentRequest) ProtoReflect() protoreflect.Message
- func (x *DeploymentRequest) Reset()
- func (x *DeploymentRequest) String() string
- type DeploymentRequestVariable
- func (*DeploymentRequestVariable) Descriptor() ([]byte, []int)deprecated
- func (x *DeploymentRequestVariable) GetName() string
- func (x *DeploymentRequestVariable) GetSecret() bool
- func (x *DeploymentRequestVariable) GetValue() string
- func (*DeploymentRequestVariable) ProtoMessage()
- func (x *DeploymentRequestVariable) ProtoReflect() protoreflect.Message
- func (x *DeploymentRequestVariable) Reset()
- func (x *DeploymentRequestVariable) String() string
- type DeploymentRequest_Action
- func (DeploymentRequest_Action) Descriptor() protoreflect.EnumDescriptor
- func (x DeploymentRequest_Action) Enum() *DeploymentRequest_Action
- func (DeploymentRequest_Action) EnumDescriptor() ([]byte, []int)deprecated
- func (x DeploymentRequest_Action) Number() protoreflect.EnumNumber
- func (x DeploymentRequest_Action) String() string
- func (DeploymentRequest_Action) Type() protoreflect.EnumType
- type DeploymentServiceClient
- type DeploymentServiceServer
- type RetrieveDeploymentRequest
- func (*RetrieveDeploymentRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RetrieveDeploymentRequest) GetId() int32
- func (*RetrieveDeploymentRequest) ProtoMessage()
- func (x *RetrieveDeploymentRequest) ProtoReflect() protoreflect.Message
- func (x *RetrieveDeploymentRequest) Reset()
- func (x *RetrieveDeploymentRequest) String() string
- type UnimplementedDeploymentServiceServer
- type UnsafeDeploymentServiceServer
Constants ¶
const (
DeploymentService_Get_FullMethodName = "/terrapi.v1.DeploymentService/Get"
)
Variables ¶
var ( DeploymentRequest_Action_name = map[int32]string{ 0: "init", 1: "plan", 2: "apply", 3: "destroy", } DeploymentRequest_Action_value = map[string]int32{ "init": 0, "plan": 1, "apply": 2, "destroy": 3, } )
Enum value maps for DeploymentRequest_Action.
var DeploymentService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "terrapi.v1.DeploymentService", HandlerType: (*DeploymentServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Get", Handler: _DeploymentService_Get_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "deployment/deployment.proto", }
DeploymentService_ServiceDesc is the grpc.ServiceDesc for DeploymentService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_deployment_deployment_proto protoreflect.FileDescriptor
Functions ¶
func RegisterDeploymentServiceServer ¶
func RegisterDeploymentServiceServer(s grpc.ServiceRegistrar, srv DeploymentServiceServer)
Types ¶
type Deployment ¶
type Deployment struct {
Module *DeploymentModule `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
Request *DeploymentRequest `protobuf:"bytes,2,opt,name=request,proto3" json:"request,omitempty"`
// contains filtered or unexported fields
}
func (*Deployment) Descriptor
deprecated
func (*Deployment) Descriptor() ([]byte, []int)
Deprecated: Use Deployment.ProtoReflect.Descriptor instead.
func (*Deployment) GetModule ¶
func (x *Deployment) GetModule() *DeploymentModule
func (*Deployment) GetRequest ¶
func (x *Deployment) GetRequest() *DeploymentRequest
func (*Deployment) ProtoMessage ¶
func (*Deployment) ProtoMessage()
func (*Deployment) ProtoReflect ¶
func (x *Deployment) ProtoReflect() protoreflect.Message
func (*Deployment) Reset ¶
func (x *Deployment) Reset()
func (*Deployment) String ¶
func (x *Deployment) String() string
type DeploymentModule ¶
type DeploymentModule struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Address string `protobuf:"bytes,2,opt,name=address,proto3" json:"address,omitempty"`
Path string `protobuf:"bytes,3,opt,name=path,proto3" json:"path,omitempty"`
Username string `protobuf:"bytes,4,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,5,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*DeploymentModule) Descriptor
deprecated
func (*DeploymentModule) Descriptor() ([]byte, []int)
Deprecated: Use DeploymentModule.ProtoReflect.Descriptor instead.
func (*DeploymentModule) GetAddress ¶
func (x *DeploymentModule) GetAddress() string
func (*DeploymentModule) GetName ¶
func (x *DeploymentModule) GetName() string
func (*DeploymentModule) GetPassword ¶
func (x *DeploymentModule) GetPassword() string
func (*DeploymentModule) GetPath ¶
func (x *DeploymentModule) GetPath() string
func (*DeploymentModule) GetUsername ¶
func (x *DeploymentModule) GetUsername() string
func (*DeploymentModule) ProtoMessage ¶
func (*DeploymentModule) ProtoMessage()
func (*DeploymentModule) ProtoReflect ¶
func (x *DeploymentModule) ProtoReflect() protoreflect.Message
func (*DeploymentModule) Reset ¶
func (x *DeploymentModule) Reset()
func (*DeploymentModule) String ¶
func (x *DeploymentModule) String() string
type DeploymentRequest ¶
type DeploymentRequest struct {
Action DeploymentRequest_Action `protobuf:"varint,1,opt,name=action,proto3,enum=terrapi.v1.DeploymentRequest_Action" json:"action,omitempty"`
Variables []*DeploymentRequestVariable `protobuf:"bytes,2,rep,name=variables,proto3" json:"variables,omitempty"`
// contains filtered or unexported fields
}
func (*DeploymentRequest) Descriptor
deprecated
func (*DeploymentRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeploymentRequest.ProtoReflect.Descriptor instead.
func (*DeploymentRequest) GetAction ¶
func (x *DeploymentRequest) GetAction() DeploymentRequest_Action
func (*DeploymentRequest) GetVariables ¶
func (x *DeploymentRequest) GetVariables() []*DeploymentRequestVariable
func (*DeploymentRequest) ProtoMessage ¶
func (*DeploymentRequest) ProtoMessage()
func (*DeploymentRequest) ProtoReflect ¶
func (x *DeploymentRequest) ProtoReflect() protoreflect.Message
func (*DeploymentRequest) Reset ¶
func (x *DeploymentRequest) Reset()
func (*DeploymentRequest) String ¶
func (x *DeploymentRequest) String() string
type DeploymentRequestVariable ¶
type DeploymentRequestVariable struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
Secret bool `protobuf:"varint,3,opt,name=secret,proto3" json:"secret,omitempty"`
// contains filtered or unexported fields
}
func (*DeploymentRequestVariable) Descriptor
deprecated
func (*DeploymentRequestVariable) Descriptor() ([]byte, []int)
Deprecated: Use DeploymentRequestVariable.ProtoReflect.Descriptor instead.
func (*DeploymentRequestVariable) GetName ¶
func (x *DeploymentRequestVariable) GetName() string
func (*DeploymentRequestVariable) GetSecret ¶
func (x *DeploymentRequestVariable) GetSecret() bool
func (*DeploymentRequestVariable) GetValue ¶
func (x *DeploymentRequestVariable) GetValue() string
func (*DeploymentRequestVariable) ProtoMessage ¶
func (*DeploymentRequestVariable) ProtoMessage()
func (*DeploymentRequestVariable) ProtoReflect ¶
func (x *DeploymentRequestVariable) ProtoReflect() protoreflect.Message
func (*DeploymentRequestVariable) Reset ¶
func (x *DeploymentRequestVariable) Reset()
func (*DeploymentRequestVariable) String ¶
func (x *DeploymentRequestVariable) String() string
type DeploymentRequest_Action ¶
type DeploymentRequest_Action int32
const ( DeploymentRequest_init DeploymentRequest_Action = 0 DeploymentRequest_plan DeploymentRequest_Action = 1 DeploymentRequest_apply DeploymentRequest_Action = 2 DeploymentRequest_destroy DeploymentRequest_Action = 3 )
func (DeploymentRequest_Action) Descriptor ¶
func (DeploymentRequest_Action) Descriptor() protoreflect.EnumDescriptor
func (DeploymentRequest_Action) Enum ¶
func (x DeploymentRequest_Action) Enum() *DeploymentRequest_Action
func (DeploymentRequest_Action) EnumDescriptor
deprecated
func (DeploymentRequest_Action) EnumDescriptor() ([]byte, []int)
Deprecated: Use DeploymentRequest_Action.Descriptor instead.
func (DeploymentRequest_Action) Number ¶
func (x DeploymentRequest_Action) Number() protoreflect.EnumNumber
func (DeploymentRequest_Action) String ¶
func (x DeploymentRequest_Action) String() string
func (DeploymentRequest_Action) Type ¶
func (DeploymentRequest_Action) Type() protoreflect.EnumType
type DeploymentServiceClient ¶
type DeploymentServiceClient interface {
Get(ctx context.Context, in *RetrieveDeploymentRequest, opts ...grpc.CallOption) (*Deployment, error)
}
DeploymentServiceClient is the client API for DeploymentService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDeploymentServiceClient ¶
func NewDeploymentServiceClient(cc grpc.ClientConnInterface) DeploymentServiceClient
type DeploymentServiceServer ¶
type DeploymentServiceServer interface {
Get(context.Context, *RetrieveDeploymentRequest) (*Deployment, error)
// contains filtered or unexported methods
}
DeploymentServiceServer is the server API for DeploymentService service. All implementations must embed UnimplementedDeploymentServiceServer for forward compatibility.
type RetrieveDeploymentRequest ¶
type RetrieveDeploymentRequest struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*RetrieveDeploymentRequest) Descriptor
deprecated
func (*RetrieveDeploymentRequest) Descriptor() ([]byte, []int)
Deprecated: Use RetrieveDeploymentRequest.ProtoReflect.Descriptor instead.
func (*RetrieveDeploymentRequest) GetId ¶
func (x *RetrieveDeploymentRequest) GetId() int32
func (*RetrieveDeploymentRequest) ProtoMessage ¶
func (*RetrieveDeploymentRequest) ProtoMessage()
func (*RetrieveDeploymentRequest) ProtoReflect ¶
func (x *RetrieveDeploymentRequest) ProtoReflect() protoreflect.Message
func (*RetrieveDeploymentRequest) Reset ¶
func (x *RetrieveDeploymentRequest) Reset()
func (*RetrieveDeploymentRequest) String ¶
func (x *RetrieveDeploymentRequest) String() string
type UnimplementedDeploymentServiceServer ¶
type UnimplementedDeploymentServiceServer struct{}
UnimplementedDeploymentServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDeploymentServiceServer) Get ¶ added in v1.1.0
func (UnimplementedDeploymentServiceServer) Get(context.Context, *RetrieveDeploymentRequest) (*Deployment, error)
type UnsafeDeploymentServiceServer ¶
type UnsafeDeploymentServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDeploymentServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DeploymentServiceServer will result in compilation errors.